import { DataLegendRowFormatEventArgs as DataLegendRowFormatEventArgs_internal } from "./DataLegendRowFormatEventArgs";
import { ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents event argument for StylingDataRow, StylingSummaryRow, and StylingHeaderRow events.
*/
export class IgrDataLegendRowFormatEventArgs {
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new DataLegendRowFormatEventArgs_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets or sets whether the legend badge is visible in the Data Legend
    */
    get isBadgeVisible() {
        return this.i.isBadgeVisible;
    }
    set isBadgeVisible(v) {
        this.i.isBadgeVisible = ensureBool(v);
    }
    /**
     * Gets or sets whether the whole row is visible in the Data Legend
    */
    get isRowVisible() {
        return this.i.isRowVisible;
    }
    set isRowVisible(v) {
        this.i.isRowVisible = ensureBool(v);
    }
    /**
     * Gets actual value of series that will be formatted in row of Data Legend
    */
    get actualValue() {
        return this.i.actualValue;
    }
    set actualValue(v) {
        this.i.actualValue = +v;
    }
    /**
     * Gets or sets label text displayed in row of Data Legend
    */
    get titleText() {
        return this.i.titleText;
    }
    set titleText(v) {
        this.i.titleText = v;
    }
    /**
     * Gets or sets value text displayed in row of Data Legend
    */
    get valueText() {
        return this.i.valueText;
    }
    set valueText(v) {
        this.i.valueText = v;
    }
    /**
     * Gets or sets unit text displayed in row of Data Legend
    */
    get unitsText() {
        return this.i.unitsText;
    }
    set unitsText(v) {
        this.i.unitsText = v;
    }
    /**
     * Gets index of series in added to the chart's series collection.
    */
    get seriesIndex() {
        return this.i.seriesIndex;
    }
    set seriesIndex(v) {
        this.i.seriesIndex = +v;
    }
    /**
     * Gets or sets color of label text
    */
    get titleTextColor() {
        return brushToString(this.i.titleTextColor);
    }
    set titleTextColor(v) {
        this.i.titleTextColor = stringToBrush(v);
    }
    /**
     * Gets or sets color of value text
    */
    get unitsTextColor() {
        return brushToString(this.i.unitsTextColor);
    }
    set unitsTextColor(v) {
        this.i.unitsTextColor = stringToBrush(v);
    }
    /**
     * Gets or sets color of unit text
    */
    get valueTextColor() {
        return brushToString(this.i.valueTextColor);
    }
    set valueTextColor(v) {
        this.i.valueTextColor = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get unitsTextFont() {
        if (this.i.unitsTextFont == null) {
            return null;
        }
        return this.i.unitsTextFont.fontString;
    }
    set unitsTextFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.unitsTextFont = fi;
    }
    /**
     * Gets or Sets the style to use for the Value text.
    */
    get valueTextFont() {
        if (this.i.valueTextFont == null) {
            return null;
        }
        return this.i.valueTextFont.fontString;
    }
    set valueTextFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.valueTextFont = fi;
    }
    /**
     * Gets or Sets the style to use for the Title text.
    */
    get titleTextFont() {
        if (this.i.titleTextFont == null) {
            return null;
        }
        return this.i.titleTextFont.fontString;
    }
    set titleTextFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.titleTextFont = fi;
    }
}
