import * as React from 'react';
import { XamDataLegend } from "./XamDataLegend";
import { arrayFindByName, ensureEnum, brushToString, stringToBrush, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { DataAbbreviationMode_$type } from './DataAbbreviationMode';
import { DataLegendUnitsMode_$type } from './DataLegendUnitsMode';
import { DataLegendSummaryType_$type } from './DataLegendSummaryType';
import { IgrDataLegendSummaryCalculationEventArgs } from './igr-data-legend-summary-calculation-event-args';
import { IgrDataLegendRowFormatEventArgs } from './igr-data-legend-row-format-event-args';
const DataLegendStylingDefaults = {};
/**
 * Represents data legend that displays information about each series including values and summaries.
 * THIS IS A COMMUNITY TECHNOLOGY PREVIEW, not for use in production.
*/
export class IgrDataLegend extends React.Component {
    constructor(props) {
        super(props);
        this._wrapper = null;
        this._implementation = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._calculateSummaryValue = null;
        this._calculateSummaryValue_wrapped = null;
        this._formatHeaderRow = null;
        this._formatHeaderRow_wrapped = null;
        this._formatSeriesRow = null;
        this._formatSeriesRow_wrapped = null;
        this._formatSummaryRow = null;
        this._formatSummaryRow_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        this._implementation = this.createImplementation();
        if (document) {
            this._container = document.createElement("div");
            this._container.style.display = "block";
            this._container.style.width = "100%";
            this._container.style.height = "100%";
        }
        var root;
        root = this._container;
        if (this._container != null) {
            root = this._container;
        }
        var ren = new ReactRenderer(root, document, true, DataLegendStylingDefaults);
        this._wrapper = ren;
        var dataLegend = this.i;
        this._dataLegend = dataLegend;
        this._dataLegend.externalObject = this;
        dataLegend.provideContainer(ren);
        dataLegend.notifySizeChanged();
        if (props) {
            this.initializeProperties();
        }
        ren.addSizeWatcher(() => {
            this._dataLegend.notifySizeChanged();
        });
    }
    set height(value) {
        this._height = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this._dataLegend.notifySizeChanged();
        }
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this._dataLegend.notifySizeChanged();
        }
    }
    desiredSizeChanged(width, height) {
        if (this.width == undefined || this.width == '') {
            this._elRef.style.width = width + "px";
        }
        if (this.height == undefined || this.height == '') {
            this._elRef.style.height = height + "px";
        }
        this._dataLegend.notifySizeChanged();
    }
    get width() {
        return this._width;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    render() {
        let div = React.createElement("div", {
            className: "ig-data-legend igr-data-legend",
            ref: this._getMainRef
        });
        //}
        return div;
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    componentWillUnmount() {
        this._dataLegend.destroy();
        this._wrapper.destroy();
    }
    componentDidMount() {
        this._elRef.style.width = this._width ? this._width : "";
        this._elRef.style.height = this._height ? this._height : "";
        this._elRef.appendChild(this._container);
        this._dataLegend.notifySizeChanged();
        this.initializeContent();
    }
    initializeContent() {
        this.updateStyle();
    }
    createImplementation() {
        return new XamDataLegend();
    }
    get i() {
        return this._implementation;
    }
    static _staticStyling(container, component, parent) {
        let genericPrefix = "";
        let typeName = (component.i ? component.i : component).$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("DataLegend");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = (component.i ? component.i : component).$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, component, genericPrefix + "-", new Set(), false, additionalPrefixes);
    }
    /**
     * Gets or sets the target for the data legend.
    */
    get target() {
        var ret = this.i.target;
        if (ret.externalObject != null) {
            ret = ret.externalObject;
        }
        return ret;
    }
    set target(v) {
        if (v._implementation) {
            v = v._implementation;
        }
        this.i.target = v;
    }
    /**
 * Gets actual mode for abbreviating numbers based on all numbers in the legend
*/
    get actualAbbreviationMode() {
        return this.i.al;
    }
    set actualAbbreviationMode(v) {
        this.i.al = ensureEnum(DataAbbreviationMode_$type, v);
    }
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
    */
    get formatAbbreviationMode() {
        return this.i.am;
    }
    set formatAbbreviationMode(v) {
        this.i.am = ensureEnum(DataAbbreviationMode_$type, v);
    }
    /**
     * Gets or sets maximum digits for formating numbers displayed in the legend
    */
    get formatMaximumDigits() {
        return this.i.bq;
    }
    set formatMaximumDigits(v) {
        this.i.bq = +v;
    }
    /**
     * Gets or sets minimum digits for formating numbers displayed in the legend
    */
    get formatMinimumDigits() {
        return this.i.br;
    }
    set formatMinimumDigits(v) {
        this.i.br = +v;
    }
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get headerText() {
        return this.i.b7;
    }
    set headerText(v) {
        this.i.b7 = v;
    }
    /**
     * Gets or sets the header text color.
    */
    get headerTextColor() {
        return brushToString(this.i.et);
    }
    set headerTextColor(v) {
        this.i.et = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the header text.
    */
    get headerTextFont() {
        if (this.i.a5 == null) {
            return null;
        }
        return this.i.a5.fontString;
    }
    set headerTextFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.a5 = fi;
    }
    /**
     * Gets or sets the summary text color.
    */
    get summaryTextColor() {
        return brushToString(this.i.ex);
    }
    set summaryTextColor(v) {
        this.i.ex = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get summaryTextFont() {
        if (this.i.a9 == null) {
            return null;
        }
        return this.i.a9.fontString;
    }
    set summaryTextFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.a9 = fi;
    }
    /**
     * Gets or sets the summary value color.
    */
    get summaryValueColor() {
        return brushToString(this.i.ey);
    }
    set summaryValueColor(v) {
        this.i.ey = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the summary value.
    */
    get summaryValueFont() {
        if (this.i.ba == null) {
            return null;
        }
        return this.i.ba.fontString;
    }
    set summaryValueFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ba = fi;
    }
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get summaryType() {
        return this.i.au;
    }
    set summaryType(v) {
        this.i.au = ensureEnum(DataLegendSummaryType_$type, v);
    }
    /**
     * Gets or sets the SummaryValueFormat for the data legend.
    */
    get summaryValueFormat() {
        return this.i.cz;
    }
    set summaryValueFormat(v) {
        this.i.cz = v;
    }
    /**
     * Gets or sets the format specifiers to use with the SummaryValueFormat string.
    */
    get summaryValueFormatSpecifiers() {
        return this.i.ai;
    }
    set summaryValueFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.ai = v;
    }
    /**
     * Gets or sets the SummaryText for the data legend.
    */
    get summaryText() {
        return this.i.cs;
    }
    set summaryText(v) {
        this.i.cs = v;
    }
    get rowMarginBottom() {
        return this.i.e7 ? this.i.e7.b : NaN;
    }
    set rowMarginBottom(v) {
        this.ensureRowMargin();
        this.i.e7.b = +v;
        this.i.e7 = this.i.e7;
    }
    get rowMarginLeft() {
        return this.i.e7 ? this.i.e7.c : NaN;
    }
    set rowMarginLeft(v) {
        this.ensureRowMargin();
        this.i.e7.c = +v;
        this.i.e7 = this.i.e7;
    }
    get rowMarginRight() {
        return this.i.e7 ? this.i.e7.d : NaN;
    }
    set rowMarginRight(v) {
        this.ensureRowMargin();
        this.i.e7.d = +v;
        this.i.e7 = this.i.e7;
    }
    get rowMarginTop() {
        return this.i.e7 ? this.i.e7.e : NaN;
    }
    set rowMarginTop(v) {
        this.ensureRowMargin();
        this.i.e7.e = +v;
        this.i.e7 = this.i.e7;
    }
    ensureRowMargin() {
        if (this.i.e7) {
            return;
        }
        this.i.e7 = new Thickness(2);
    }
    /**
     * Gets or sets the ColumnMargin for the data legend.
    */
    get columnSpacing() {
        return this.i.bn;
    }
    set columnSpacing(v) {
        this.i.bn = +v;
    }
    get badgeMarginBottom() {
        return this.i.e6 ? this.i.e6.b : NaN;
    }
    set badgeMarginBottom(v) {
        this.ensureBadgeMargin();
        this.i.e6.b = +v;
        this.i.e6 = this.i.e6;
    }
    get badgeMarginLeft() {
        return this.i.e6 ? this.i.e6.c : NaN;
    }
    set badgeMarginLeft(v) {
        this.ensureBadgeMargin();
        this.i.e6.c = +v;
        this.i.e6 = this.i.e6;
    }
    get badgeMarginRight() {
        return this.i.e6 ? this.i.e6.d : NaN;
    }
    set badgeMarginRight(v) {
        this.ensureBadgeMargin();
        this.i.e6.d = +v;
        this.i.e6 = this.i.e6;
    }
    get badgeMarginTop() {
        return this.i.e6 ? this.i.e6.e : NaN;
    }
    set badgeMarginTop(v) {
        this.ensureBadgeMargin();
        this.i.e6.e = +v;
        this.i.e6 = this.i.e6;
    }
    ensureBadgeMargin() {
        if (this.i.e6) {
            return;
        }
        this.i.e6 = new Thickness(2);
    }
    get seriesTitleMarginBottom() {
        return this.i.e8 ? this.i.e8.b : NaN;
    }
    set seriesTitleMarginBottom(v) {
        this.ensureSeriesTitleMargin();
        this.i.e8.b = +v;
        this.i.e8 = this.i.e8;
    }
    get seriesTitleMarginLeft() {
        return this.i.e8 ? this.i.e8.c : NaN;
    }
    set seriesTitleMarginLeft(v) {
        this.ensureSeriesTitleMargin();
        this.i.e8.c = +v;
        this.i.e8 = this.i.e8;
    }
    get seriesTitleMarginRight() {
        return this.i.e8 ? this.i.e8.d : NaN;
    }
    set seriesTitleMarginRight(v) {
        this.ensureSeriesTitleMargin();
        this.i.e8.d = +v;
        this.i.e8 = this.i.e8;
    }
    get seriesTitleMarginTop() {
        return this.i.e8 ? this.i.e8.e : NaN;
    }
    set seriesTitleMarginTop(v) {
        this.ensureSeriesTitleMargin();
        this.i.e8.e = +v;
        this.i.e8 = this.i.e8;
    }
    ensureSeriesTitleMargin() {
        if (this.i.e8) {
            return;
        }
        this.i.e8 = new Thickness(2);
    }
    get seriesValueMarginBottom() {
        return this.i.e9 ? this.i.e9.b : NaN;
    }
    set seriesValueMarginBottom(v) {
        this.ensureSeriesValueMargin();
        this.i.e9.b = +v;
        this.i.e9 = this.i.e9;
    }
    get seriesValueMarginLeft() {
        return this.i.e9 ? this.i.e9.c : NaN;
    }
    set seriesValueMarginLeft(v) {
        this.ensureSeriesValueMargin();
        this.i.e9.c = +v;
        this.i.e9 = this.i.e9;
    }
    get seriesValueMarginRight() {
        return this.i.e9 ? this.i.e9.d : NaN;
    }
    set seriesValueMarginRight(v) {
        this.ensureSeriesValueMargin();
        this.i.e9.d = +v;
        this.i.e9 = this.i.e9;
    }
    get seriesValueMarginTop() {
        return this.i.e9 ? this.i.e9.e : NaN;
    }
    set seriesValueMarginTop(v) {
        this.ensureSeriesValueMargin();
        this.i.e9.e = +v;
        this.i.e9 = this.i.e9;
    }
    ensureSeriesValueMargin() {
        if (this.i.e9) {
            return;
        }
        this.i.e9 = new Thickness(2);
    }
    /**
     * Gets or sets the TargetCursorPositionX for the data legend.
    */
    get targetCursorPositionX() {
        return this.i.targetCursorPositionX;
    }
    set targetCursorPositionX(v) {
        this.i.targetCursorPositionX = +v;
    }
    /**
     * Gets or sets the TargetCursorPositionY for the data legend.
    */
    get targetCursorPositionY() {
        return this.i.targetCursorPositionY;
    }
    set targetCursorPositionY(v) {
        this.i.targetCursorPositionY = +v;
    }
    /**
     * Gets or sets the TargetAxisValue for the data legend.
    */
    get targetAxisValue() {
        return this.i.bu;
    }
    set targetAxisValue(v) {
        this.i.bu = v;
    }
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get seriesUnitsMode() {
        return this.i.av;
    }
    set seriesUnitsMode(v) {
        this.i.av = ensureEnum(DataLegendUnitsMode_$type, v);
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get seriesUnitsText() {
        return this.i.cn;
    }
    set seriesUnitsText(v) {
        this.i.cn = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get seriesUnitsColor() {
        return brushToString(this.i.ev);
    }
    set seriesUnitsColor(v) {
        this.i.ev = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get seriesUnitsFont() {
        if (this.i.a7 == null) {
            return null;
        }
        return this.i.a7.fontString;
    }
    set seriesUnitsFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.a7 = fi;
    }
    /**
     * Gets or sets the units text color.
    */
    get seriesValueColor() {
        return brushToString(this.i.ew);
    }
    set seriesValueColor(v) {
        this.i.ew = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get seriesValueFont() {
        if (this.i.a8 == null) {
            return null;
        }
        return this.i.a8.fontString;
    }
    set seriesValueFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.a8 = fi;
    }
    /**
     * Gets or sets the display text color.
    */
    get seriesTitleColor() {
        return brushToString(this.i.eu);
    }
    set seriesTitleColor(v) {
        this.i.eu = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the display text.
    */
    get seriesTitleFont() {
        if (this.i.a6 == null) {
            return null;
        }
        return this.i.a6.fontString;
    }
    set seriesTitleFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.a6 = fi;
    }
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    get pixelScalingRatio() {
        return this.i.bo;
    }
    set pixelScalingRatio(v) {
        this.i.bo = +v;
    }
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    get actualPixelScalingRatio() {
        return this.i.bm;
    }
    set actualPixelScalingRatio(v) {
        this.i.bm = +v;
    }
    findByName(name) {
        if (this.summaryValueFormatSpecifiers != null && arrayFindByName(this.summaryValueFormatSpecifiers, name)) {
            return arrayFindByName(this.summaryValueFormatSpecifiers, name);
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("DataLegend");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    /**
 * Notifies the legend about changes to size

*/
    notifySizeChanged() {
        this.i.notifySizeChanged();
    }
    /**
     * Forces any pending refresh to the legend to be finished.
    
    */
    flush() {
        this.i.de();
    }
    getAbbreviatedValue(value, mode, minDigits, maxDigits) {
        let iv = this.i.b6(value, (mode == null ? null : mode), minDigits, maxDigits);
        return (iv);
    }
    getAbbreviatedSymbol(value, mode, minDigits, maxDigits) {
        let iv = this.i.b5(value, (mode == null ? null : mode), minDigits, maxDigits);
        return (iv);
    }
    getAbbreviatedString(value, mode, minDigits, maxDigits) {
        let iv = this.i.b4(value, (mode == null ? null : mode), minDigits, maxDigits);
        return (iv);
    }
    /**
     * Event raised when calculating summary value.
    */
    get calculateSummaryValue() {
        return this._calculateSummaryValue;
    }
    set calculateSummaryValue(ev) {
        if (this._calculateSummaryValue_wrapped !== null) {
            this.i.calculateSummaryValue = delegateRemove(this.i.calculateSummaryValue, this._calculateSummaryValue_wrapped);
            this._calculateSummaryValue_wrapped = null;
            this._calculateSummaryValue = null;
        }
        this._calculateSummaryValue = ev;
        this._calculateSummaryValue_wrapped = (o, e) => {
            let outerArgs = new IgrDataLegendSummaryCalculationEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeCalculateSummaryValue) {
                this.beforeCalculateSummaryValue(this, outerArgs);
            }
            if (this._calculateSummaryValue) {
                this._calculateSummaryValue(this, outerArgs);
            }
        };
        this.i.calculateSummaryValue = delegateCombine(this.i.calculateSummaryValue, this._calculateSummaryValue_wrapped);
        ;
    }
    /**
     * Event raised when the Header row is formatted and styled.
    */
    get formatHeaderRow() {
        return this._formatHeaderRow;
    }
    set formatHeaderRow(ev) {
        if (this._formatHeaderRow_wrapped !== null) {
            this.i.formatHeaderRow = delegateRemove(this.i.formatHeaderRow, this._formatHeaderRow_wrapped);
            this._formatHeaderRow_wrapped = null;
            this._formatHeaderRow = null;
        }
        this._formatHeaderRow = ev;
        this._formatHeaderRow_wrapped = (o, e) => {
            let outerArgs = new IgrDataLegendRowFormatEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeFormatHeaderRow) {
                this.beforeFormatHeaderRow(this, outerArgs);
            }
            if (this._formatHeaderRow) {
                this._formatHeaderRow(this, outerArgs);
            }
        };
        this.i.formatHeaderRow = delegateCombine(this.i.formatHeaderRow, this._formatHeaderRow_wrapped);
        ;
    }
    /**
     * Event raised when the series row is formatted and styled.
    */
    get formatSeriesRow() {
        return this._formatSeriesRow;
    }
    set formatSeriesRow(ev) {
        if (this._formatSeriesRow_wrapped !== null) {
            this.i.formatSeriesRow = delegateRemove(this.i.formatSeriesRow, this._formatSeriesRow_wrapped);
            this._formatSeriesRow_wrapped = null;
            this._formatSeriesRow = null;
        }
        this._formatSeriesRow = ev;
        this._formatSeriesRow_wrapped = (o, e) => {
            let outerArgs = new IgrDataLegendRowFormatEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeFormatSeriesRow) {
                this.beforeFormatSeriesRow(this, outerArgs);
            }
            if (this._formatSeriesRow) {
                this._formatSeriesRow(this, outerArgs);
            }
        };
        this.i.formatSeriesRow = delegateCombine(this.i.formatSeriesRow, this._formatSeriesRow_wrapped);
        ;
    }
    /**
     * Event raised when the summary row is formatted and styled.
    */
    get formatSummaryRow() {
        return this._formatSummaryRow;
    }
    set formatSummaryRow(ev) {
        if (this._formatSummaryRow_wrapped !== null) {
            this.i.formatSummaryRow = delegateRemove(this.i.formatSummaryRow, this._formatSummaryRow_wrapped);
            this._formatSummaryRow_wrapped = null;
            this._formatSummaryRow = null;
        }
        this._formatSummaryRow = ev;
        this._formatSummaryRow_wrapped = (o, e) => {
            let outerArgs = new IgrDataLegendRowFormatEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeFormatSummaryRow) {
                this.beforeFormatSummaryRow(this, outerArgs);
            }
            if (this._formatSummaryRow) {
                this._formatSummaryRow(this, outerArgs);
            }
        };
        this.i.formatSummaryRow = delegateCombine(this.i.formatSummaryRow, this._formatSummaryRow_wrapped);
        ;
    }
}
