import { IgrValueBrushScale } from "./igr-value-brush-scale";
import { IgrContourValueResolver } from "./igr-contour-value-resolver";
import { IgrScatterTriangulationSeries } from "./igr-scatter-triangulation-series";
import { ScatterContourSeries } from "./ScatterContourSeries";
/**
 * Series class for rendering isarithmic contours based on a triangulation of X+Y+Value points in the ItemsSource.
*/
export class IgrScatterContourSeries extends IgrScatterTriangulationSeries {
    createImplementation() {
        return new ScatterContourSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows a line contour shape.
    */
    get isLineContour() {
        return this.i.dw;
    }
    /**
     * Gets or set the name of the property from which to retrieve the numeric values from the ItemsSource items.
    */
    get valueMemberPath() {
        return this.i.ri;
    }
    set valueMemberPath(v) {
        this.i.ri = v;
    }
    /**
     * Gets or sets the ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
    */
    get fillScale() {
        if (this.i.rc == null) {
            return null;
        }
        if (!this.i.rc.externalObject) {
            let e = IgrValueBrushScale._createFromInternal(this.i.rc);
            if (e) {
                e._implementation = this.i.rc;
            }
            this.i.rc.externalObject = e;
        }
        return this.i.rc.externalObject;
    }
    set fillScale(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.rc = null : this.i.rc = v.i;
    }
    /**
     * Gets actual fill scale that is set on the FillScale property or default FillScale
    */
    get actualFillScale() {
        if (this.i.rb == null) {
            return null;
        }
        if (!this.i.rb.externalObject) {
            let e = IgrValueBrushScale._createFromInternal(this.i.rb);
            if (e) {
                e._implementation = this.i.rb;
            }
            this.i.rb.externalObject = e;
        }
        return this.i.rb.externalObject;
    }
    set actualFillScale(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.rb = null : this.i.rb = v.i;
    }
    /**
     * Gets or set the ContourValueResolver used to determine the numeric values of contours.
    */
    get valueResolver() {
        if (this.i.q9 == null) {
            return null;
        }
        if (!this.i.q9.externalObject) {
            let e = IgrContourValueResolver._createFromInternal(this.i.q9);
            if (e) {
                e._implementation = this.i.q9;
            }
            this.i.q9.externalObject = e;
        }
        return this.i.q9.externalObject;
    }
    set valueResolver(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.q9 = null : this.i.q9 = v.i;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        if (this.actualFillScale && this.actualFillScale.name && this.actualFillScale.name == name) {
            return this.actualFillScale;
        }
        if (this.valueResolver && this.valueResolver.name && this.valueResolver.name == name) {
            return this.valueResolver;
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        if (this.actualFillScale && this.actualFillScale._styling) {
            this.actualFillScale._styling(container, component, this);
        }
        if (this.valueResolver && this.valueResolver._styling) {
            this.valueResolver._styling(container, component, this);
        }
        this._inStyling = false;
    }
    getItemValue(item, memberPathName) {
        let iv = this.i.hn(item, memberPathName);
        return (iv);
    }
}
