import { DataLegendRowFormatEventArgs as DataLegendRowFormatEventArgs_internal } from "./DataLegendRowFormatEventArgs";
import { ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents event argument for StylingDataRow, StylingSummaryRow, and StylingHeaderRow events.
*/
var IgrDataLegendRowFormatEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrDataLegendRowFormatEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrDataLegendRowFormatEventArgs.prototype.createImplementation = function () {
        return new DataLegendRowFormatEventArgs_internal();
    };
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDataLegendRowFormatEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrDataLegendRowFormatEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "isBadgeVisible", {
        /**
         * Gets or sets whether the legend badge is visible in the Data Legend
        */
        get: function () {
            return this.i.isBadgeVisible;
        },
        set: function (v) {
            this.i.isBadgeVisible = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "isRowVisible", {
        /**
         * Gets or sets whether the whole row is visible in the Data Legend
        */
        get: function () {
            return this.i.isRowVisible;
        },
        set: function (v) {
            this.i.isRowVisible = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "actualValue", {
        /**
         * Gets actual value of series that will be formatted in row of Data Legend
        */
        get: function () {
            return this.i.actualValue;
        },
        set: function (v) {
            this.i.actualValue = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "titleText", {
        /**
         * Gets or sets label text displayed in row of Data Legend
        */
        get: function () {
            return this.i.titleText;
        },
        set: function (v) {
            this.i.titleText = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "valueText", {
        /**
         * Gets or sets value text displayed in row of Data Legend
        */
        get: function () {
            return this.i.valueText;
        },
        set: function (v) {
            this.i.valueText = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "unitsText", {
        /**
         * Gets or sets unit text displayed in row of Data Legend
        */
        get: function () {
            return this.i.unitsText;
        },
        set: function (v) {
            this.i.unitsText = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "seriesIndex", {
        /**
         * Gets index of series in added to the chart's series collection.
        */
        get: function () {
            return this.i.seriesIndex;
        },
        set: function (v) {
            this.i.seriesIndex = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "titleTextColor", {
        /**
         * Gets or sets color of label text
        */
        get: function () {
            return brushToString(this.i.titleTextColor);
        },
        set: function (v) {
            this.i.titleTextColor = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "unitsTextColor", {
        /**
         * Gets or sets color of value text
        */
        get: function () {
            return brushToString(this.i.unitsTextColor);
        },
        set: function (v) {
            this.i.unitsTextColor = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "valueTextColor", {
        /**
         * Gets or sets color of unit text
        */
        get: function () {
            return brushToString(this.i.valueTextColor);
        },
        set: function (v) {
            this.i.valueTextColor = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "unitsTextFont", {
        /**
         * Gets or Sets the style to use for the units text.
        */
        get: function () {
            if (this.i.unitsTextFont == null) {
                return null;
            }
            return this.i.unitsTextFont.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.unitsTextFont = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "valueTextFont", {
        /**
         * Gets or Sets the style to use for the Value text.
        */
        get: function () {
            if (this.i.valueTextFont == null) {
                return null;
            }
            return this.i.valueTextFont.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.valueTextFont = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataLegendRowFormatEventArgs.prototype, "titleTextFont", {
        /**
         * Gets or Sets the style to use for the Title text.
        */
        get: function () {
            if (this.i.titleTextFont == null) {
                return null;
            }
            return this.i.titleTextFont.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.titleTextFont = fi;
        },
        enumerable: false,
        configurable: true
    });
    return IgrDataLegendRowFormatEventArgs;
}());
export { IgrDataLegendRowFormatEventArgs };
