import * as React from 'react';
import { XamDataLegend } from "./XamDataLegend";
import { DataAbbreviationMode } from './DataAbbreviationMode';
import { DataLegendUnitsMode } from './DataLegendUnitsMode';
import { DataLegendSummaryType } from './DataLegendSummaryType';
import { IgrDataLegendSummaryCalculationEventArgs } from './igr-data-legend-summary-calculation-event-args';
import { IgrDataLegendRowFormatEventArgs } from './igr-data-legend-row-format-event-args';
/**
 * Represents data legend that displays information about each series including values and summaries.
 * THIS IS A COMMUNITY TECHNOLOGY PREVIEW, not for use in production.
*/
export declare class IgrDataLegend extends React.Component<IIgrDataLegendProps> {
    private _container;
    private _height;
    private _width;
    private _initialized;
    private _elRef;
    set height(value: string);
    get height(): string;
    set width(value: string);
    private desiredSizeChanged;
    get width(): string;
    private _wrapper;
    private _getMainRef;
    render(): React.DetailedReactHTMLElement<{
        className: string;
        ref: (ref: any) => void;
    }, any>;
    constructor(props: IIgrDataLegendProps);
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    protected initializeProperties(): void;
    updateStyle(): void;
    componentWillUnmount(): void;
    private _implementation;
    componentDidMount(): void;
    initializeContent(): void;
    protected createImplementation(): XamDataLegend;
    get i(): XamDataLegend;
    private _dataLegend;
    protected static _staticStyling(container: any, component: any, parent?: any): void;
    /**
     * Gets or sets the target for the data legend.
    */
    get target(): any;
    set target(v: any);
    /**
 * Gets actual mode for abbreviating numbers based on all numbers in the legend
*/
    get actualAbbreviationMode(): DataAbbreviationMode;
    set actualAbbreviationMode(v: DataAbbreviationMode);
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
    */
    get formatAbbreviationMode(): DataAbbreviationMode;
    set formatAbbreviationMode(v: DataAbbreviationMode);
    /**
     * Gets or sets maximum digits for formating numbers displayed in the legend
    */
    get formatMaximumDigits(): number;
    set formatMaximumDigits(v: number);
    /**
     * Gets or sets minimum digits for formating numbers displayed in the legend
    */
    get formatMinimumDigits(): number;
    set formatMinimumDigits(v: number);
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get headerText(): string;
    set headerText(v: string);
    /**
     * Gets or sets the header text color.
    */
    get headerTextColor(): string;
    set headerTextColor(v: string);
    /**
     * Gets or Sets the style to use for the header text.
    */
    get headerTextFont(): string;
    set headerTextFont(v: string);
    /**
     * Gets or sets the summary text color.
    */
    get summaryTextColor(): string;
    set summaryTextColor(v: string);
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get summaryTextFont(): string;
    set summaryTextFont(v: string);
    /**
     * Gets or sets the summary value color.
    */
    get summaryValueColor(): string;
    set summaryValueColor(v: string);
    /**
     * Gets or Sets the style to use for the summary value.
    */
    get summaryValueFont(): string;
    set summaryValueFont(v: string);
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get summaryType(): DataLegendSummaryType;
    set summaryType(v: DataLegendSummaryType);
    /**
     * Gets or sets the SummaryValueFormat for the data legend.
    */
    get summaryValueFormat(): string;
    set summaryValueFormat(v: string);
    /**
     * Gets or sets the format specifiers to use with the SummaryValueFormat string.
    */
    get summaryValueFormatSpecifiers(): any[];
    set summaryValueFormatSpecifiers(v: any[]);
    /**
     * Gets or sets the SummaryText for the data legend.
    */
    get summaryText(): string;
    set summaryText(v: string);
    get rowMarginBottom(): number;
    set rowMarginBottom(v: number);
    get rowMarginLeft(): number;
    set rowMarginLeft(v: number);
    get rowMarginRight(): number;
    set rowMarginRight(v: number);
    get rowMarginTop(): number;
    set rowMarginTop(v: number);
    ensureRowMargin(): void;
    /**
     * Gets or sets the ColumnMargin for the data legend.
    */
    get columnSpacing(): number;
    set columnSpacing(v: number);
    get badgeMarginBottom(): number;
    set badgeMarginBottom(v: number);
    get badgeMarginLeft(): number;
    set badgeMarginLeft(v: number);
    get badgeMarginRight(): number;
    set badgeMarginRight(v: number);
    get badgeMarginTop(): number;
    set badgeMarginTop(v: number);
    ensureBadgeMargin(): void;
    get seriesTitleMarginBottom(): number;
    set seriesTitleMarginBottom(v: number);
    get seriesTitleMarginLeft(): number;
    set seriesTitleMarginLeft(v: number);
    get seriesTitleMarginRight(): number;
    set seriesTitleMarginRight(v: number);
    get seriesTitleMarginTop(): number;
    set seriesTitleMarginTop(v: number);
    ensureSeriesTitleMargin(): void;
    get seriesValueMarginBottom(): number;
    set seriesValueMarginBottom(v: number);
    get seriesValueMarginLeft(): number;
    set seriesValueMarginLeft(v: number);
    get seriesValueMarginRight(): number;
    set seriesValueMarginRight(v: number);
    get seriesValueMarginTop(): number;
    set seriesValueMarginTop(v: number);
    ensureSeriesValueMargin(): void;
    /**
     * Gets or sets the TargetCursorPositionX for the data legend.
    */
    get targetCursorPositionX(): number;
    set targetCursorPositionX(v: number);
    /**
     * Gets or sets the TargetCursorPositionY for the data legend.
    */
    get targetCursorPositionY(): number;
    set targetCursorPositionY(v: number);
    /**
     * Gets or sets the TargetAxisValue for the data legend.
    */
    get targetAxisValue(): any;
    set targetAxisValue(v: any);
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get seriesUnitsMode(): DataLegendUnitsMode;
    set seriesUnitsMode(v: DataLegendUnitsMode);
    /**
     * Gets or sets the units text for the data legend.
    */
    get seriesUnitsText(): string;
    set seriesUnitsText(v: string);
    /**
     * Gets or sets the units text color.
    */
    get seriesUnitsColor(): string;
    set seriesUnitsColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get seriesUnitsFont(): string;
    set seriesUnitsFont(v: string);
    /**
     * Gets or sets the units text color.
    */
    get seriesValueColor(): string;
    set seriesValueColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get seriesValueFont(): string;
    set seriesValueFont(v: string);
    /**
     * Gets or sets the display text color.
    */
    get seriesTitleColor(): string;
    set seriesTitleColor(v: string);
    /**
     * Gets or Sets the style to use for the display text.
    */
    get seriesTitleFont(): string;
    set seriesTitleFont(v: string);
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    get pixelScalingRatio(): number;
    set pixelScalingRatio(v: number);
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    get actualPixelScalingRatio(): number;
    set actualPixelScalingRatio(v: number);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Notifies the legend about changes to size

*/
    notifySizeChanged(): void;
    /**
     * Forces any pending refresh to the legend to be finished.
    
    */
    flush(): void;
    getAbbreviatedValue(value: number, mode: DataAbbreviationMode, minDigits: number, maxDigits: number): string;
    getAbbreviatedSymbol(value: number, mode: DataAbbreviationMode, minDigits: number, maxDigits: number): string;
    getAbbreviatedString(value: number, mode: DataAbbreviationMode, minDigits: number, maxDigits: number): string;
    private _calculateSummaryValue;
    private _calculateSummaryValue_wrapped;
    /**
     * Event raised when calculating summary value.
    */
    get calculateSummaryValue(): (s: IgrDataLegend, e: IgrDataLegendSummaryCalculationEventArgs) => void;
    set calculateSummaryValue(ev: (s: IgrDataLegend, e: IgrDataLegendSummaryCalculationEventArgs) => void);
    private _formatHeaderRow;
    private _formatHeaderRow_wrapped;
    /**
     * Event raised when the Header row is formatted and styled.
    */
    get formatHeaderRow(): (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void;
    set formatHeaderRow(ev: (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void);
    private _formatSeriesRow;
    private _formatSeriesRow_wrapped;
    /**
     * Event raised when the series row is formatted and styled.
    */
    get formatSeriesRow(): (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void;
    set formatSeriesRow(ev: (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void);
    private _formatSummaryRow;
    private _formatSummaryRow_wrapped;
    /**
     * Event raised when the summary row is formatted and styled.
    */
    get formatSummaryRow(): (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void;
    set formatSummaryRow(ev: (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void);
}
export interface IIgrDataLegendProps {
    width?: string;
    height?: string;
    /**
 * Gets actual mode for abbreviating numbers based on all numbers in the legend
*/
    actualAbbreviationMode?: DataAbbreviationMode | string;
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
    */
    formatAbbreviationMode?: DataAbbreviationMode | string;
    /**
     * Gets or sets maximum digits for formating numbers displayed in the legend
    */
    formatMaximumDigits?: number | string;
    /**
     * Gets or sets minimum digits for formating numbers displayed in the legend
    */
    formatMinimumDigits?: number | string;
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    headerText?: string;
    /**
     * Gets or sets the header text color.
    */
    headerTextColor?: string;
    /**
     * Gets or Sets the style to use for the header text.
    */
    headerTextFont?: string;
    /**
     * Gets or sets the summary text color.
    */
    summaryTextColor?: string;
    /**
     * Gets or Sets the style to use for the summary text.
    */
    summaryTextFont?: string;
    /**
     * Gets or sets the summary value color.
    */
    summaryValueColor?: string;
    /**
     * Gets or Sets the style to use for the summary value.
    */
    summaryValueFont?: string;
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    summaryType?: DataLegendSummaryType | string;
    /**
     * Gets or sets the SummaryValueFormat for the data legend.
    */
    summaryValueFormat?: string;
    /**
     * Gets or sets the format specifiers to use with the SummaryValueFormat string.
    */
    summaryValueFormatSpecifiers?: any[];
    /**
     * Gets or sets the SummaryText for the data legend.
    */
    summaryText?: string;
    rowMarginBottom?: number | string;
    rowMarginLeft?: number | string;
    rowMarginRight?: number | string;
    rowMarginTop?: number | string;
    /**
     * Gets or sets the ColumnMargin for the data legend.
    */
    columnSpacing?: number | string;
    badgeMarginBottom?: number | string;
    badgeMarginLeft?: number | string;
    badgeMarginRight?: number | string;
    badgeMarginTop?: number | string;
    seriesTitleMarginBottom?: number | string;
    seriesTitleMarginLeft?: number | string;
    seriesTitleMarginRight?: number | string;
    seriesTitleMarginTop?: number | string;
    seriesValueMarginBottom?: number | string;
    seriesValueMarginLeft?: number | string;
    seriesValueMarginRight?: number | string;
    seriesValueMarginTop?: number | string;
    /**
     * Gets or sets the TargetCursorPositionX for the data legend.
    */
    targetCursorPositionX?: number | string;
    /**
     * Gets or sets the TargetCursorPositionY for the data legend.
    */
    targetCursorPositionY?: number | string;
    /**
     * Gets or sets the TargetAxisValue for the data legend.
    */
    targetAxisValue?: any;
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    seriesUnitsMode?: DataLegendUnitsMode | string;
    /**
     * Gets or sets the units text for the data legend.
    */
    seriesUnitsText?: string;
    /**
     * Gets or sets the units text color.
    */
    seriesUnitsColor?: string;
    /**
     * Gets or Sets the style to use for the units text.
    */
    seriesUnitsFont?: string;
    /**
     * Gets or sets the units text color.
    */
    seriesValueColor?: string;
    /**
     * Gets or Sets the style to use for the units text.
    */
    seriesValueFont?: string;
    /**
     * Gets or sets the display text color.
    */
    seriesTitleColor?: string;
    /**
     * Gets or Sets the style to use for the display text.
    */
    seriesTitleFont?: string;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    pixelScalingRatio?: number | string;
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    actualPixelScalingRatio?: number | string;
    /**
 * Event raised when calculating summary value.
*/
    calculateSummaryValue?: (s: IgrDataLegend, e: IgrDataLegendSummaryCalculationEventArgs) => void;
    /**
     * Event raised when the Header row is formatted and styled.
    */
    formatHeaderRow?: (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void;
    /**
     * Event raised when the series row is formatted and styled.
    */
    formatSeriesRow?: (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void;
    /**
     * Event raised when the summary row is formatted and styled.
    */
    formatSummaryRow?: (s: IgrDataLegend, e: IgrDataLegendRowFormatEventArgs) => void;
}
